package com.ynet.life.search;

import com.ynet.life.base.Trace;
import com.ynet.life.search.core.IndexSearch;
import com.ynet.life.search.core.IndexSearchImpl;
import com.ynet.life.search.core.IndexSource;
import com.ynet.life.search.core.IndexSourceImpl;
import com.ynet.life.search.core.SearchResult;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.lucene.document.Document;
import org.apache.lucene.search.Filter;
import org.apache.lucene.search.Sort;

/* loaded from: com_ynet_life_search.jar:com/ynet/life/search/AbstractDBIndexSearch.class */
public abstract class AbstractDBIndexSearch implements LifeIndexSearch {
    public int length;
    public int totalHits;
    private String indexFolderFile;
    private String queryString;
    private int howMany;
    private List results = null;

    protected abstract List getResultSet(Document document);

    public AbstractDBIndexSearch(String indexFolderFile, String queryString, int howMany) {
        this.indexFolderFile = indexFolderFile;
        this.queryString = queryString;
        this.howMany = howMany;
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public void setQueryString(String queryString) {
        this.queryString = queryString;
        this.results = null;
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public String getQueryString() {
        return this.queryString;
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public int resultCount() {
        if (this.results == null) {
            executeQuery();
        }
        return this.results.size();
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public int totalHits() {
        return this.totalHits;
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public Iterator results() {
        if (this.results == null) {
            executeQuery();
        }
        return this.results.iterator();
    }

    @Override // com.ynet.life.search.LifeIndexSearch
    public Iterator results(int startIndex, int numResults) {
        if (this.results == null) {
            executeQuery();
        }
        int startIndex2 = startIndex - 1;
        int i = startIndex2 + numResults;
        int endIndex = i;
        if (i > this.results.size()) {
            endIndex = this.results.size();
        }
        if (endIndex - startIndex2 < 0) {
            return this.results.iterator();
        }
        return this.results.subList(startIndex2, endIndex).iterator();
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v2 */
    /* JADX WARN: Type inference failed for: r0v24, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Throwable] */
    private void executeQuery() {
        List bankNo = new ArrayList();
        IndexSource indexSource = null;
        ?? r0 = 0;
        IndexSearch indexSearch = null;
        try {
            try {
                indexSource = new IndexSourceImpl(this.indexFolderFile);
                IndexSearch indexSearchImpl = new IndexSearchImpl(indexSource, getFilter(), getSort());
                indexSearch = indexSearchImpl;
                SearchResult resultsDoc = indexSearchImpl.search(this.queryString, this.howMany);
                this.length = resultsDoc.length;
                this.totalHits = resultsDoc.totalHits;
                for (Document document : resultsDoc.getSearchResult()) {
                    bankNo.add(getResultSet(document));
                }
                r0 = "LifeSearch";
                Trace.logDebug("LifeSearch", "检索数据");
                try {
                    indexSearch.close();
                    indexSource.close();
                } catch (Exception unused) {
                }
            } catch (Exception e) {
                Trace.log((Throwable) r0);
                if (indexSearch != null) {
                    try {
                        indexSearch.close();
                    } catch (Exception unused2) {
                    }
                }
                if (indexSource != null) {
                    indexSource.close();
                }
            }
            this.results = bankNo;
        } catch (Throwable th) {
            if (indexSearch != null) {
                try {
                    indexSearch.close();
                } catch (Exception unused3) {
                    throw th;
                }
            }
            if (indexSource != null) {
                indexSource.close();
            }
            throw th;
        }
    }

    public Sort getSort() {
        return null;
    }

    public Filter getFilter() {
        return null;
    }
}
